@@ -1,6 +1,6 @@
 import datetime as dtm
-import os
 import fcntl
+import os
 from abc import ABC, abstractmethod
 from dataclasses import asdict
 from decimal import Decimal
@@ -9,6 +9,7 @@ from typing import List, Literal, Optional, Union
 
 import numpy as np
 import pandas as pd
+from cachetools.func import ttl_cache
 
 from pyqqq.backtest.logger import Logger, get_logger
 from pyqqq.backtest.positionprovider import BasePositionProvider
@@ -20,11 +21,14 @@ from pyqqq.data.domestic import get_market_cap_by_codes
 from pyqqq.data.domestic import get_ticker_info as get_kr_ticker_info
 from pyqqq.data.minutes import get_all_day_data as get_kr_minute_data
 from pyqqq.data.us_stocks import get_all_day_data as get_us_minute_data
-from pyqqq.data.us_stocks import get_ohlcv_by_codes_for_period as get_us_daily_data
+from pyqqq.data.us_stocks import \
+    get_ohlcv_by_codes_for_period as get_us_daily_data
 from pyqqq.data.us_stocks import get_ticker_info as get_us_ticker_info
 from pyqqq.datatypes import *
 from pyqqq.utils.casting import casting
-from pyqqq.utils.market_schedule import get_last_trading_day, get_market_schedule, get_trading_day_with_offset
+from pyqqq.utils.market_schedule import (get_last_trading_day,
+                                         get_market_schedule,
+                                         get_trading_day_with_offset)
 from pyqqq.utils.position_classifier import PositionClassifier
 
 MarketType = Literal["kr_stock", "us_stock"]
@@ -597,11 +601,17 @@ class MockBroker(BaseBroker):
                     # 현재 시간 데이터가 없을 경우 전일 종가로 대체
                     last_trading_day = get_last_trading_day(today, exchange=self._get_exchange_code())
                     df = self.get_daily_price(code, last_trading_day, last_trading_day)  # 전일 종가는 일봉, 분봉 구분이 필요 없다.
-                    return typed_result(df["close"].iloc[-1])
+                    if not df.empty:
+                        return typed_result(df["close"].iloc[-1])
+                    else:
+                        return Decimal(0)
 
             elif self.time_unit == "days":
                 df = self.get_daily_price(code, today, today)
-                return typed_result(df["close"].iloc[-1])
+                if not df.empty:
+                    return typed_result(df["close"].iloc[-1])
+                else:
+                    return Decimal(0)
 
             else:
                 raise ValueError(f"Invalid time unit: {self.time_unit}")
@@ -775,6 +785,7 @@ class MockBroker(BaseBroker):
 
         return df
 
+    @ttl_cache(maxsize=100, ttl=300)
     def get_daily_price(self, code: str, from_date: Optional[dtm.date] = None, end_date: Optional[dtm.date] = None):
         """
         지정된 기간 동안의 정규장 시작부터 현재 시각 (이전) 까지의 일봉 데이터를 조회합니다.
@@ -814,6 +825,9 @@ class MockBroker(BaseBroker):
             else:
                 dfs = get_kr_daily_data([code], from_date, end_date, adjusted=True, ascending=True, exchange=DataExchange.KRX)
 
+        if code not in dfs:
+            return pd.DataFrame()
+
         df = dfs[code]
 
         if not df.empty and end_date == today:
@@ -1301,6 +1315,8 @@ class MockBroker(BaseBroker):
         dict_list = []
         for trade in self.trading_history:
             d = asdict(trade)
+            d["average_purchase_price"] = Decimal(str(d["average_purchase_price"])) if not isinstance(d["average_purchase_price"], Decimal) else d["average_purchase_price"]
+            d["pnl_rate"] = Decimal(str(d["pnl_rate"])) if not isinstance(d["pnl_rate"], Decimal) else d["pnl_rate"]
 
             if filter_side and d["side"] != filter_side:
                 continue
