@@ -25,7 +25,7 @@ class EBestStockOrder(StockOrder):
 
 class EBestSimpleDomesticStock:
     """
-    이베스트투자증권 국내 주식 API 사용하여 주식 거래를 하기 위한 클래스입니다.
+    LS(구 이베스트투자)증권 국내 주식 API 사용하여 주식 거래를 하기 위한 클래스입니다.
 
     기존 EBestDomesticStock 클래스를 감싸고, 간단한 주문/조회 기능을 제공합니다.
 
@@ -35,7 +35,7 @@ class EBestSimpleDomesticStock:
 
     def __init__(self, auth: EBestAuth):
         self.stock_api = EBestDomesticStock(auth)
-        self.logger = get_logger(__name__)
+        self.logger = get_logger(__name__ + ".EBestSimpleDomesticStock")
 
     @with_mock()
     def get_account(self) -> dict:
@@ -60,11 +60,7 @@ class EBestSimpleDomesticStock:
         purchase_amount = data["mamt"]
         evaluated_amount = data["tappamt"]
         pnl_amount = data["tdtsunik"]
-        pnl_rate = (
-            Decimal(pnl_amount / purchase_amount * 100)
-            if purchase_amount != 0
-            else Decimal(0)
-        )
+        pnl_rate = Decimal(pnl_amount / purchase_amount * 100) if purchase_amount != 0 else Decimal(0)
 
         result = {
             "total_balance": data["sunamt"],
@@ -81,9 +77,7 @@ class EBestSimpleDomesticStock:
         return result
 
     @with_mock()
-    def get_possible_quantity(
-        self, asset_code: str, order_type: OrderType = OrderType.MARKET, price: int = 0
-    ) -> dict:
+    def get_possible_quantity(self, asset_code: str, order_type: OrderType = OrderType.MARKET, price: int = 0) -> dict:
         """
         주문 가능 수량을 조회합니다.
 
@@ -134,9 +128,7 @@ class EBestSimpleDomesticStock:
         result = []
 
         while fetching:
-            r = self.stock_api.get_stock_balance(
-                tr_cont_key=tr_cont_key, cts_expcode=cts_expcode
-            )
+            r = self.stock_api.get_stock_balance(tr_cont_key=tr_cont_key, cts_expcode=cts_expcode)
 
             output1 = r["output1"]
             output2 = r["output2"]
@@ -171,7 +163,7 @@ class EBestSimpleDomesticStock:
         asset_code: str,
         first_date: dtm.date,
         last_date: dtm.date,
-        adjusted_price: bool = False,
+        adjusted_price: bool = True,
     ) -> pd.DataFrame:
         """
         일봉 데이터 검색
@@ -185,12 +177,8 @@ class EBestSimpleDomesticStock:
         Returns:
             pd.DataFrame: 일봉 데이터
         """
-        assert (
-            first_date <= last_date
-        ), "last_date는 first_date와 같거나, 이후 날짜여야 합니다"
-        assert (
-            last_date <= dtm.date.today()
-        ), "last_date는 오늘과 같거나 이전이어야 합니다."
+        assert first_date <= last_date, "last_date는 first_date와 같거나, 이후 날짜여야 합니다"
+        assert last_date <= dtm.date.today(), "last_date는 오늘과 같거나 이전이어야 합니다."
 
         cts_date = ""
         tr_cont_key = ""
@@ -285,9 +273,7 @@ class EBestSimpleDomesticStock:
                 if not item:
                     continue
 
-                datetime = dtm.datetime.strptime(
-                    f"{item['date']} {item['time']}", "%Y%m%d %H%M%S"
-                )
+                datetime = dtm.datetime.strptime(f"{item['date']} {item['time']}", "%Y%m%d %H%M%S")
 
                 result.append(
                     {
@@ -458,9 +444,7 @@ class EBestSimpleDomesticStock:
         self.logger.info(f"create_order result - {r['rsp_cd']} {r['rsp_msg']}")
 
         if "OrdNo" not in r["output2"]:
-            self.logger.error(
-                f"create_order failed. {asset_code} {side} {quantity} {order_type} {price} - {r['rsp_cd']} {r['rsp_msg']}"
-            )
+            self.logger.error(f"create_order failed. {asset_code} {side} {quantity} {order_type} {price} - {r['rsp_cd']} {r['rsp_msg']}")
 
         return r["output2"].get("OrdNo", None)
 
@@ -691,9 +675,7 @@ class EBestSimpleDomesticStock:
             else:
                 raise ValueError("지원하지 않는 주문 방향입니다.")
 
-        def __find_order_type(
-            ord_prc_ptn_code: str, ord_cndi_tp_code: str
-        ) -> OrderType:
+        def __find_order_type(ord_prc_ptn_code: str, ord_cndi_tp_code: str) -> OrderType:
             if ord_prc_ptn_code == "00":
                 if ord_cndi_tp_code == "0":
                     return OrderType.LIMIT
@@ -716,9 +698,7 @@ class EBestSimpleDomesticStock:
             result[order_no] = {
                 "side": __find_side(item["BnsTpCode"]),
                 "req_type": __find_req_type(item["MrcTpCode"]),
-                "order_type": __find_order_type(
-                    item["OrdprcPtnCode"], item["OrdCndiTpCode"]
-                ),
+                "order_type": __find_order_type(item["OrdprcPtnCode"], item["OrdCndiTpCode"]),
             }
 
         return result
@@ -754,9 +734,7 @@ class EBestSimpleDomesticStock:
 
             else:
                 tr_cont = "Y"
-                self.logger.debug(
-                    f"get_tick_data: sleep 1 for next page request. current length: {len(result)} cts_time={cts_time} tr_cont_key={tr_cont_key}"
-                )
+                self.logger.debug(f"get_tick_data: sleep 1 for next page request. current length: {len(result)} cts_time={cts_time} tr_cont_key={tr_cont_key}")
                 time.sleep(1)
 
         return result
@@ -829,33 +807,21 @@ class EBestSimpleDomesticStock:
         account_no = data["accno"]
 
         # 취소 주문의 경우 원주문번호를 사용
-        order_no = str(
-            data["orgordno"] if data["event_type"] == "cancelled" else data["ordno"]
-        )
+        order_no = str(data["orgordno"] if data["event_type"] == "cancelled" else data["ordno"])
         side = OrderSide.BUY if data["bnstp"] == "2" else OrderSide.SELL
         order_type = __find_order_type(data)
         quantity = int(data["ordqty"])
         price = int(data["ordprice"]) if "ordprice" in data else int(data["ordprc"])
         event_type = __find_status(data)
 
-        filled_quantity = (
-            int(data["execqty"]) if data.get("execqty", "").strip() != "" else None
-        )
-        filled_price = (
-            int(data["execprc"]) if data.get("execprc", "").strip() != "" else None
-        )
-        pending_quantity = (
-            int(data["unercqty"]) if data.get("unercqty", "").strip() != "" else None
-        )
+        filled_quantity = int(data["execqty"]) if data.get("execqty", "").strip() != "" else None
+        filled_price = int(data["execprc"]) if data.get("execprc", "").strip() != "" else None
+        pending_quantity = int(data["unercqty"]) if data.get("unercqty", "").strip() != "" else None
 
         filled_time = data.get("rcptexectime")
-        org_order_no = (
-            str(data.get("orgordno")) if data["event_type"] != "cancelled" else None
-        )
+        org_order_no = str(data.get("orgordno")) if data["event_type"] != "cancelled" else None
 
-        self.logger.debug(
-            f"order_event: order_no={order_no} / filled={filled_quantity} order={quantity} pending={pending_quantity} event_type={event_type}"
-        )
+        self.logger.debug(f"order_event: order_no={order_no} / filled={filled_quantity} order={quantity} pending={pending_quantity} event_type={event_type}")
 
         if filled_time is not None:
             t = dtm.datetime.strptime(filled_time, "%H%M%S%f").time()
