@@ -1,15 +1,19 @@
+import asyncio
+import datetime as dtm
+import json
+import random
+import ssl
+import traceback
 from enum import Enum
+from typing import AsyncGenerator, Callable
+
+import requests
+import websockets
+
 from pyqqq.brokerage.ebest.oauth import EBestAuth
 from pyqqq.utils.logger import get_logger
 from pyqqq.utils.market_schedule import *
 from pyqqq.utils.retry import retry
-from typing import AsyncGenerator, Callable
-import asyncio
-import json
-import ssl
-import random
-import requests
-import websockets
 
 
 class EBestTRClient:
@@ -26,18 +30,10 @@ class EBestTRClient:
     def __init__(self, auth: EBestAuth, corp_data: dict = None):
         self.auth = auth
         self.corp_data = corp_data
+        self.session = requests.Session()
 
-    @retry(requests.HTTPError)
-    def request(
-        self,
-        path: str,
-        tr_cd: str,
-        tr_cont: str = "N",
-        tr_cont_key: str = "",
-        params: dict = None,
-        body: dict = None,
-        method: str = "POST",
-    ):
+    @retry(requests.RequestException, delay=1)
+    def request(self, path: str, tr_cd: str, tr_cont: str = "N", tr_cont_key: str = "", params: dict = None, body: dict = None, method: str = "POST"):
         """
         TR 요청을 보내고 응답을 받는 메서드
 
@@ -67,13 +63,14 @@ class EBestTRClient:
 
         url = f"{self.auth.host_url}{path}"
 
-        r = requests.request(method=method, url=url, headers=headers, params=params, json=body)
+        r = self.session.request(method=method, url=url, headers=headers, params=params, json=body)
 
         if r.status_code != 200:
             try:
                 res_body = r.json()
                 if "rsp_cd" in res_body and res_body["rsp_cd"] == "IGW00121":
                     self.auth.get_token(refresh=True)
+
             except Exception as e:
                 self.logger.exception(e)
 
@@ -189,7 +186,14 @@ class EBestTRWebsocketClient:
 
             except ssl.SSLZeroReturnError:
                 self.logger.error(f"{self.session_id}: SSLZeroReturnError")
-                await asyncio.sleep(0.5)
+
+                if not hasattr(self, "_sslzero_exc_count"):
+                    self._sslzero_exc_count = 0
+                if self._sslzero_exc_count < 3:
+                    self._sslzero_exc_count += 1
+                    traceback.print_exc()
+
+                await asyncio.sleep(random.uniform(1, 2))
                 continue
 
             except TimeoutError as e:
