@@ -474,11 +474,21 @@ class KISSimpleDomesticStock:
         r = get_all_last_trades()
         result = []
 
+        # get_all_last_trades 결과에서 ETN 구분이 없으므로 원래 코드에서 "Q"를 제거한 코드로 검색
+        codes = [code[1:] if code.startswith("Q") else code for code in asset_codes]
+
         for item in r:
-            if item["shcode"] in asset_codes:
+            if item["shcode"] in codes:
+                # 해당 종목이 ETN 인지 확인
+                is_etn = False
+                for code in asset_codes:
+                    if code.startswith("Q") and code[1:] == item["shcode"]:
+                        is_etn = True
+                        break
+
                 result.append(
                     {
-                        "code": item["shcode"],
+                        "code": "Q" + item["shcode"] if is_etn else item["shcode"],
                         "current_price": item["price"],
                         "volume": item["volume"],
                         "open_price": item["open"],
@@ -885,7 +895,7 @@ class KISSimpleDomesticStock:
         ctx_area_nk100 = ""
         tr_cont = ""
 
-        pending_order_list = [item.order_no for item in self.get_pending_orders()]
+        pending_order_list = [item.order_no for item in self.get_pending_orders(exchanges)]
 
         if target_date is None:
             target_date = dtm.date.today()
@@ -957,7 +967,7 @@ class KISSimpleDomesticStock:
         Returns:
             StockOrder: 주문 정보
         """
-        result = self.get_today_order_history(order_no=odno)
+        result = self.get_today_order_history(order_no=odno, exchanges=list(OrderExchange))
         if len(result) > 0:
             return result[0]
         else:
@@ -1097,8 +1107,10 @@ class KISSimpleDomesticStock:
             event_type = "rejected"
         elif cancelled:
             event_type = "cancelled"
-            order_no = org_order_no  # 취소 주문의 경우 원주문번호로 변경
-            org_order_no = None
+            # IOC 취소될땐 org_order_no가 비어있어서 오류 발생함
+            if org_order_no:
+                order_no = org_order_no  # 취소 주문의 경우 원주문번호로 변경
+                org_order_no = None
         elif accepted or updated:
             event_type = "accepted"
         elif executed:
