@@ -12,20 +12,22 @@ import websockets
 class KISTRClient:
     logger = get_logger(__name__ + ".KISTRClient")
 
-    '''
+    """
     한국투자증권 TR 요청을 위한 클라이언트
 
     Args:
         auth (KISAuth): 인증 정보를 담고 있는 객체
         corp_data (dict): 기업 고객의 경우 추가로 필요한 정보를 담고 있는 객체
-    '''
+    """
+
     def __init__(self, auth: KISAuth, corp_data: dict = None):
         self.auth = auth
         self.corp_data = corp_data
+        self.session = requests.Session()
 
-    @retry(requests.HTTPError)
-    def request(self, path: str, tr_id: str, tr_cont: str = '', params: dict = None, body: dict = None, method: str = 'GET'):
-        '''
+    @retry(requests.RequestException)
+    def request(self, path: str, tr_id: str, tr_cont: str = "", params: dict = None, body: dict = None, method: str = "GET"):
+        """
         TR 요청을 보내고 응답을 받는 메서드
 
         Args:
@@ -41,28 +43,22 @@ class KISTRClient:
 
         Raises:
             requests.HTTPError: 요청이 실패한 경우
-        '''
+        """
         headers = {
-            'content-type': 'application/json; charset=utf-8',
-            'authorization': f'Bearer {self.auth.get_token()}',
-            'appkey': self.auth.appkey,
-            'appsecret': self.auth.appsecret,
-            'custtype': 'P' if self.corp_data is None else 'B',
-            'tr_id': tr_id,
-            'tr_cont': tr_cont,
+            "content-type": "application/json; charset=utf-8",
+            "authorization": f"Bearer {self.auth.get_token()}",
+            "appkey": self.auth.appkey,
+            "appsecret": self.auth.appsecret,
+            "custtype": "P" if self.corp_data is None else "B",
+            "tr_id": tr_id,
+            "tr_cont": tr_cont,
         }
         if self.corp_data is not None:
             headers.update(self.corp_data)
 
         url = f"{self.auth.host_url}{path}"
 
-        r = requests.request(
-            method=method,
-            url=url,
-            headers=headers,
-            params=params,
-            json=body
-        )
+        r = self.session.request(method=method, url=url, headers=headers, params=params, json=body)
 
         if r.status_code != 200:
             try:
@@ -136,21 +132,22 @@ class KISTRWebsocketClient:
                             yield data
 
             except websockets.exceptions.ConnectionClosedError:
-                # self.logger.error(f"{self.session_id}: ConnectionClosedError")
+                self.logger.error(f"{self.session_id}: ConnectionClosedError")
                 await asyncio.sleep(0.5)
                 continue
 
             except ConnectionRefusedError:
+                self.logger.error(f"{self.session_id}: ConnectionRefusedError")
                 await asyncio.sleep(0.5)
                 continue
 
-            except websockets.ConnectionClosed as e:
+            except websockets.ConnectionClosed:
+                self.logger.error(f"{self.session_id}: ConnectionClosed")
                 await asyncio.sleep(0.5)
-                self.logger.exception(e)
                 continue
 
-            except ssl.SSLZeroReturnError as e:
-                self.logger.exception(e)
+            except ssl.SSLZeroReturnError:
+                self.logger.error(f"{self.session_id}: SSLZeroReturnError")
                 await asyncio.sleep(0.5)
                 continue
 
@@ -160,9 +157,7 @@ class KISTRWebsocketClient:
                 await asyncio.sleep(1)
                 continue
 
-    async def recv_with_timeout(
-        self, ws: websockets.WebSocketClientProtocol, timeout: int = 1
-    ) -> str:
+    async def recv_with_timeout(self, ws: websockets.WebSocketClientProtocol, timeout: int = 1) -> str:
         """timeout 초 동안 수신을 대기하고 수신이 없으면 None을 반환한다"""
         try:
             message = await asyncio.wait_for(ws.recv(), timeout=timeout)
