@@ -31,6 +31,7 @@ class TrackerSocket:
         self.stop_event = asyncio.Event()
         self.logger = get_logger(__name__ + ".TrackerSocket")
         self.trading_tracker_counter = 1
+        self.only_my_account = True
         self.event_callbacks: Dict[callable] = {}
 
     async def start(self):
@@ -64,6 +65,9 @@ class TrackerSocket:
         Args:
             event (OrderEvent): 주문 이벤트 객체
         """
+        if event is None or (self.only_my_account and not self._check_account_match(event.account_no)):
+            return
+
         self.logger.debug(f"Relay order event: {event}")
 
         for callback in self.event_callbacks.values():
@@ -120,6 +124,20 @@ class TrackerSocket:
 
         self.task = asyncio.create_task(self._monitor_schedule())
 
+    def _check_account_match(self, event_account_no):
+        my_account_no = f"{self.simple_api.account_no}{self.simple_api.account_product_code}"
+
+        if event_account_no is not None and my_account_no == event_account_no:
+            return True
+        else:
+            return False
+
+    def activate_all_account_event(self):
+        """
+        내 hts_id에 연동된 모든 계좌의 주문을 수신하도록 설정합니다.
+        """
+        self.only_my_account = False
+
 
 class TradingTracker:
     """
